@@ -41,18 +41,21 @@ typedef struct EphyEmbed EphyEmbed;
 typedef struct EphyEmbedPrivate EphyEmbedPrivate;
 
 struct EphyEmbed {
-  GtkScrolledWindow parent_instance;
+  GtkVBox parent_instance;
 
   /*< private >*/
   EphyEmbedPrivate *priv;
 };
 
 struct EphyEmbedClass {
-  GtkScrolledWindowClass parent_class;
+  GtkVBoxClass parent_class;
 };
 
-GType        ephy_embed_get_type     (void);
-EphyWebView* ephy_embed_get_web_view (EphyEmbed *embed);
+GType        ephy_embed_get_type          (void);
+EphyWebView* ephy_embed_get_web_view      (EphyEmbed *embed);
+void         ephy_embed_add_top_widget    (EphyEmbed *embed, GtkWidget *widget, gboolean destroy_on_transition);
+void         ephy_embed_remove_top_widget (EphyEmbed *embed, GtkWidget *widget);
+void         ephy_embed_auto_download_url (EphyEmbed *embed, const char *url);
 
 G_END_DECLS
 
