@@ -104,9 +104,9 @@ update_location_editable (EphyWindow *window,
 		/* embed is NULL on startup */
 		if (embed != NULL)
 		{
-			address = ephy_web_view_get_location (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed), TRUE);
-			ephy_toolbar_set_location (EPHY_TOOLBAR (toolbar), address, NULL);
-			ephy_web_view_set_typed_address (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed), NULL);
+			address = ephy_web_view_get_location (ephy_embed_get_web_view (embed), TRUE);
+			ephy_toolbar_set_location (EPHY_TOOLBAR (toolbar), address);
+			ephy_web_view_set_typed_address (ephy_embed_get_web_view (embed), NULL);
 			g_free (address);
 		}
 	}
@@ -151,10 +151,6 @@ update_window (EphyWindow *window,
 	action = gtk_action_group_get_action (action_group, "ViewToolbar");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, !writable);
 
-	writable = eel_gconf_key_is_writable (CONF_WINDOWS_SHOW_STATUSBAR);
-	action = gtk_action_group_get_action (action_group, "ViewStatusbar");
-	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, !writable);
-
 	disabled = eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_ARBITRARY_URL);
 	action = gtk_action_group_get_action (action_group, "GoLocation");
 	ephy_action_change_sensitivity_flags (action, LOCKDOWN_FLAG, disabled);
